@@ -7,9 +7,6 @@
 #include <geos_c.h>
 
 // suggested BDR 111114
-#if GEOS_VERSION_MAJOR > 3
-#define  HAVE_UNARYUNION 1
-#endif
 #if GEOS_VERSION_MAJOR == 3
 #if GEOS_VERSION_MINOR >= 3
 #define  HAVE_UNARYUNION 1
@@ -17,11 +14,16 @@
 #endif
 
 #if GEOS_VERSION_MAJOR > 3
+#define  HAVE_UNARYUNION 1
 #define  HAVE_DELAUNAY 1
 #define HAVE_NODE 1
 #define HAVE_NEARESTPOINTS 1
 #define HAVE_MAKEVALID 1
+#define HAVE_COVERAGEUNION 1
+#define HAVE_MINIMUMROTATEDRECTANGLE 1
+#define HAVE_MAXIMUMINSSCRIBEDCIRCLE 1
 #endif
+
 #if GEOS_VERSION_MAJOR == 3
 #if GEOS_VERSION_MINOR >= 4
 #define  HAVE_DELAUNAY 1
@@ -29,6 +31,7 @@
 #define HAVE_NEARESTPOINTS 1
 #endif
 #endif
+
 #if GEOS_VERSION_MAJOR == 3
 #if GEOS_VERSION_MINOR >= 8
 #define HAVE_MAKEVALID 1
@@ -36,6 +39,19 @@
 #endif
 #endif
 
+#if GEOS_VERSION_MAJOR == 3
+#if GEOS_VERSION_MINOR >= 9
+#define HAVE_MINIMUMROTATEDRECTANGLE 1
+#define HAVE_MAXIMUMINSSCRIBEDCIRCLE 1
+#endif
+#endif
+
+
+#if GEOS_VERSION_MAJOR == 3
+#if GEOS_VERSION_MINOR >= 10
+#define HAVE_MAKEVALIDPARAMS 1
+#endif
+#endif
 
 
 /* use same define in package's local_stubs.c file */
@@ -135,6 +151,12 @@ SEXP rgeos_delaunaytriangulation(SEXP env, SEXP obj, SEXP tol,
 #ifdef HAVE_COVERAGEUNION
 SEXP rgeos_coverageunion(SEXP env, SEXP obj, SEXP id, SEXP byid );
 #endif
+#ifdef HAVE_MINIMUMROTATEDRECTANGLE
+SEXP rgeos_minimumrotatedrectangle(SEXP env, SEXP obj, SEXP id, SEXP byid);
+#endif
+#ifdef HAVE_MAXIMUMINSSCRIBEDCIRCLE
+SEXP rgeos_maximuminscribedcircle(SEXP env, SEXP obj, SEXP id, SEXP byid, SEXP tol);
+#endif
 
 typedef GEOSGeometry* (*p_topofunc)(GEOSContextHandle_t, const GEOSGeometry*);
 SEXP rgeos_topologyfunc(SEXP env, SEXP obj, SEXP id, SEXP byid, p_topofunc);
@@ -147,6 +169,10 @@ SEXP rgeos_node(SEXP env, SEXP obj);
 #ifdef HAVE_MAKEVALID
 SEXP rgeos_makevalid(SEXP env, SEXP obj, SEXP id, SEXP byid );
 #endif
+#ifdef HAVE_MAKEVALIDPARAMS
+SEXP rgeos_makevalidparams(SEXP env, SEXP obj, SEXP id, SEXP byid );
+#endif
+
 
 // Binary Topology Functions - rgeos_topology_binary.c
 SEXP rgeos_difference(SEXP env, SEXP geom1, SEXP geom2, SEXP byid, SEXP ids);
